@@ -37,22 +37,6 @@ from .transforms import (
     FiveCrop,
     TenCrop,
     InterpolationMode,
-    ToNumpy,
-    ColorJitter,
-)
-from .random_erasing import RandomErasing
-from .auto_augment import (
-    AutoAugment,
-    RandAugment,
-    AugMixAugment,
-    rand_augment_transform,
-    augment_and_mix_transform,
-    auto_augment_transform,
-)
-from .transforms_factory import (
-    create_transform,
-    transforms_imagenet_eval,
-    transforms_imagenet_train,
 )
 
 __all__ = [
@@ -79,16 +63,4 @@ __all__ = [
     "FiveCrop",
     "TenCrop",
     "InterpolationMode",
-    "ToNumpy",
-    "ColorJitter",
-    "RandomErasing",
-    "AutoAugment",
-    "RandAugment",
-    "AugMixAugment",
-    "rand_augment_transform",
-    "augment_and_mix_transform",
-    "auto_augment_transform",
-    "create_transform",
-    "transforms_imagenet_eval",
-    "transforms_imagenet_train",
 ]
